# Changelog

## 1.0.0 (2025-01-06)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/Avido-AI/avido-py/compare/v0.1.0-alpha.1...v1.0.0)

### Chores

* update SDK settings ([#6](https://github.com/Avido-AI/avido-py/issues/6)) ([7514925](https://github.com/Avido-AI/avido-py/commit/7514925d253e9c99cc6f94b054b3a085bc06eed6))

## 0.1.0-alpha.1 (2025-01-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/Avido-AI/avido-py/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([a8a1a3a](https://github.com/Avido-AI/avido-py/commit/a8a1a3a3ab26f5d33038e4fb32911c7030398e86))
* **api:** update via SDK Studio ([5e6cc7c](https://github.com/Avido-AI/avido-py/commit/5e6cc7cb4ccfb1bcb8f70311969319dcd087daa3))
* **api:** update via SDK Studio ([d59c381](https://github.com/Avido-AI/avido-py/commit/d59c3818a8037ea0f62f5562032fe0130bd614ab))
* **api:** update via SDK Studio ([24d4494](https://github.com/Avido-AI/avido-py/commit/24d44943efc49ae7a8effd5c0ca6ee41e2727234))
* **api:** update via SDK Studio ([fac078e](https://github.com/Avido-AI/avido-py/commit/fac078e32794c9b44e05d127906914e075293d94))
* **api:** update via SDK Studio ([4dd8dc7](https://github.com/Avido-AI/avido-py/commit/4dd8dc7e4eda290498f2e356905dc1573e0645b6))
* **api:** update via SDK Studio ([1601603](https://github.com/Avido-AI/avido-py/commit/16016038e1a8a0da4a07056a63125a7580edf94d))
* **api:** update via SDK Studio ([7893ff8](https://github.com/Avido-AI/avido-py/commit/7893ff86f62b0914e1480f27689060327c1b3c6d))
* **api:** update via SDK Studio ([0fcef05](https://github.com/Avido-AI/avido-py/commit/0fcef05a4471dfa6df21806402a1fe122cd8f0d6))
* **api:** update via SDK Studio ([a66c23c](https://github.com/Avido-AI/avido-py/commit/a66c23c7c508ebdc0110ac4fe274807d0ee2b093))
* **api:** update via SDK Studio ([dc17892](https://github.com/Avido-AI/avido-py/commit/dc178922d71b2501ef4c18ea56ce715a3d959dc5))


### Chores

* go live ([#1](https://github.com/Avido-AI/avido-py/issues/1)) ([b92b753](https://github.com/Avido-AI/avido-py/commit/b92b753e80237da9b48b76af67ee57cb1da2ecce))
* go live ([#4](https://github.com/Avido-AI/avido-py/issues/4)) ([2a7def0](https://github.com/Avido-AI/avido-py/commit/2a7def013625d8ea2b7051c9330865bb168bd9d9))
* update SDK settings ([#3](https://github.com/Avido-AI/avido-py/issues/3)) ([7cebf61](https://github.com/Avido-AI/avido-py/commit/7cebf61017cfb04a8a5b3c905c205986902ccc58))
